==> apptics_flutter-0.0.3.tar.gz: test/apptics_flutter_test.dart <==
import 'package:apptics_flutter/apptics_flutter_method_channel.dart';
import 'package:apptics_flutter/apptics_flutter_platform_interface.dart';
import 'package:apptics_flutter/apptics_flutter_util.dart';
import 'package:apptics_flutter/rateus/popup_action.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockAppticsFlutterPlatform
    with MockPlatformInterfaceMixin
    implements AppticsFlutterPlatform {

  @override
  Future<String?> getPlatformVersion() => Future.value('42');

  @override
  Future<void> addEvent(String? event, String? group, Map<String, dynamic>? properties) {
    // TODO: implement addEvent
    throw UnimplementedError();
  }

  @override
  Future<void> checkAndUpdateAlert(BuildContext context) {
    // TODO: implement checkAndUpdateAlert
    throw UnimplementedError();
  }

  @override
  Future<Map<String, dynamic>?> getInAppUpdateData() {
    // TODO: implement getInAppUpdateData
    throw UnimplementedError();
  }

  @override
  Future<TrackingState?> getTrackingState() {
    // TODO: implement getTrackingState
    throw UnimplementedError();
  }

  @override
  Future<bool?> isUserLoggedIn() {
    // TODO: implement isUserLoggedIn
    throw UnimplementedError();
  }

  @override
  Future<void> onClickIgnore() {
    // TODO: implement onClickIgnore
    throw UnimplementedError();
  }

  @override
  Future<void> onClickNonSupportAlert() {
    // TODO: implement onClickNonSupportAlert
    throw UnimplementedError();
  }

  @override
  Future<void> onClickReminder() {
    // TODO: implement onClickReminder
    throw UnimplementedError();
  }

  @override
  Future<void> onClickUpdate() {
    // TODO: implement onClickUpdate
    throw UnimplementedError();
  }

  @override
  Future<void> onSendImpressionStatus(String updateId) {
    // TODO: implement onSendImpressionStatus
    throw UnimplementedError();
  }

  @override
  Future<void> openPrivacySettings() {
    // TODO: implement openPrivacySettings
    throw UnimplementedError();
  }

  @override
  Future<void> presentPrivacyReviewPopup() {
    // TODO: implement presentPrivacyReviewPopup
    throw UnimplementedError();
  }

  @override
  Future<void> screenAttached(String screen_name) {
    // TODO: implement screenAttached
    throw UnimplementedError();
  }

  @override
  Future<void> screenDetached(String screen_name) {
    // TODO: implement screenDetached
    throw UnimplementedError();
  }

  @override
  Future<void> setCrashCustomProperty(Map<String, dynamic> properties) {
    // TODO: implement setCrashCustomProperty
    throw UnimplementedError();
  }

  @override
  Future<void> setDefaultLanguage(String lang) {
    // TODO: implement setDefaultLanguage
    throw UnimplementedError();
  }

  @override
  Future<void> setTrackingState(TrackingState status) {
    // TODO: implement setTrackingState
    throw UnimplementedError();
  }

  @override
  Future<void> setUser(String? user_id) {
    // TODO: implement setUser
    throw UnimplementedError();
  }

  @override
  Future<void> showLastSessionCrashedPopup() {
    // TODO: implement showLastSessionCrashedPopup
    throw UnimplementedError();
  }

  @override
  Future<int?> checkForRatingPop() {
    // TODO: implement checkForRatingPop
    throw UnimplementedError();
  }

  @override
  Future<bool?> isAppticsFeedbackModuleAvailable() {
    // TODO: implement isAppticsFeedbackModuleAvailable
    throw UnimplementedError();
  }

  @override
  // TODO: implement daysBeforeShowingPopupAgain
  int get daysBeforeShowingPopupAgain => throw UnimplementedError();

  @override
  // TODO: implement disableAutoPromptOnFulFillingCriteria
  bool get disableAutoPromptOnFulFillingCriteria => throw UnimplementedError();

  @override
  // TODO: implement disableIfNotInstalledFromPlayStore
  bool get disableIfNotInstalledFromPlayStore => throw UnimplementedError();

  @override
  // TODO: implement maxTimesToShowPopup
  int get maxTimesToShowPopup => throw UnimplementedError();

  @override
  Future<void> openFeedbackScreen() {
    // TODO: implement openFeedbackScreen
    throw UnimplementedError();
  }

  @override
  Future<void> setDaysBeforeShowingPopupAgain(int dayCount) {
    // TODO: implement setDaysBeforeShowingPopupAgain
    throw UnimplementedError();
  }

  @override
  Future<void> setDisableAutoPromptOnFulFillingCriteria(bool isDisable) {
    // TODO: implement setDisableAutoPromptOnFulFillingCriteria
    throw UnimplementedError();
  }

  @override
  Future<void> setDisableIfNotInstalledFromPlayStore(bool ifNotInstalledFromPlayStore) {
    // TODO: implement setDisableIfNotInstalledFromPlayStore
    throw UnimplementedError();
  }

  @override
  Future<void> setMaxTimesToShowPopup(int maxTime) {
    // TODO: implement setMaxTimesToShowPopup
    throw UnimplementedError();
  }

  @override
  Future<void> setShowAndroidPlayCoreAlertOnFulFillingCriteria(bool isShow) {
    // TODO: implement setShowAndroidPlayCoreAlertOnFulFillingCriteria
    throw UnimplementedError();
  }

  @override
  // TODO: implement showAndroidPlayCoreAlertOnFulFillingCriteria
  bool get showAndroidPlayCoreAlertOnFulFillingCriteria => throw UnimplementedError();

  @override
  Future<void> openPlayStore() {
    // TODO: implement openPlayStore
    throw UnimplementedError();
  }

  @override
  Future<void> sentRatingStats(int criteriaId, PopupAction popupAction) {
    // TODO: implement sentRatingStats
    throw UnimplementedError();
  }


  @override
  Future<void> hardReset() {
    // TODO: implement hardReset
    throw UnimplementedError();
  }

  @override
  Future<void> setCustomConditionValue(String key, String value) {
    // TODO: implement setCustomConditionValue
    throw UnimplementedError();
  }

  @override
  Future<void> setShowStoreAlertOnFulFillingCriteria(bool isShow) {
    // TODO: implement setShowStoreAlertOnFulFillingCriteria
    throw UnimplementedError();
  }

  @override
  // TODO: implement showStoreAlertOnFulFillingCriteria
  bool get showStoreAlertOnFulFillingCriteria => throw UnimplementedError();

  @override
  Future<String?> getStringValue(String key, {bool coldFetch = false, bool fallbackWithOfflineValue = false}) {
    // TODO: implement getStringValue
    throw UnimplementedError();
  }

  @override
  Future<void> updateRatingShown() {
    // TODO: implement updateRatingShown
    throw UnimplementedError();
  }
}

void main() {
  final AppticsFlutterPlatform initialPlatform = AppticsFlutterPlatform.instance;

  test('$MethodChannelAppticsFlutter is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelAppticsFlutter>());
  });

}

==> apptics_flutter-0.0.4.tar.gz: test/apptics_flutter_test.dart <==
import 'package:apptics_flutter/apptics_flutter_method_channel.dart';
import 'package:apptics_flutter/apptics_flutter_platform_interface.dart';
import 'package:apptics_flutter/apptics_flutter_util.dart';
import 'package:apptics_flutter/rateus/popup_action.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockAppticsFlutterPlatform
    with MockPlatformInterfaceMixin
    implements AppticsFlutterPlatform {


  @override
  Future<void> addEvent(String? event, String? group, Map<String, dynamic>? properties) {
    // TODO: implement addEvent
    throw UnimplementedError();
  }

  @override
  Future<void> checkAndUpdateAlert(BuildContext context) {
    // TODO: implement checkAndUpdateAlert
    throw UnimplementedError();
  }

  @override
  Future<Map<String, dynamic>?> getInAppUpdateData() {
    // TODO: implement getInAppUpdateData
    throw UnimplementedError();
  }

  @override
  Future<TrackingState?> getTrackingState() {
    // TODO: implement getTrackingState
    throw UnimplementedError();
  }

  @override
  Future<bool?> isUserLoggedIn() {
    // TODO: implement isUserLoggedIn
    throw UnimplementedError();
  }

  @override
  Future<void> onClickIgnore() {
    // TODO: implement onClickIgnore
    throw UnimplementedError();
  }

  @override
  Future<void> onClickNonSupportAlert() {
    // TODO: implement onClickNonSupportAlert
    throw UnimplementedError();
  }

  @override
  Future<void> onClickReminder() {
    // TODO: implement onClickReminder
    throw UnimplementedError();
  }

  @override
  Future<void> onClickUpdate() {
    // TODO: implement onClickUpdate
    throw UnimplementedError();
  }

  @override
  Future<void> onSendImpressionStatus(String updateId) {
    // TODO: implement onSendImpressionStatus
    throw UnimplementedError();
  }

  @override
  Future<void> openPrivacySettings() {
    // TODO: implement openPrivacySettings
    throw UnimplementedError();
  }

  @override
  Future<void> presentPrivacyReviewPopup() {
    // TODO: implement presentPrivacyReviewPopup
    throw UnimplementedError();
  }

  @override
  Future<void> screenAttached(String screenName) {
    // TODO: implement screenAttached
    throw UnimplementedError();
  }

  @override
  Future<void> screenDetached(String screenName) {
    // TODO: implement screenDetached
    throw UnimplementedError();
  }

  @override
  Future<void> setCrashCustomProperty(Map<String, dynamic> properties) {
    // TODO: implement setCrashCustomProperty
    throw UnimplementedError();
  }

  @override
  Future<void> setDefaultLanguage(String lang) {
    // TODO: implement setDefaultLanguage
    throw UnimplementedError();
  }

  @override
  Future<void> setTrackingState(TrackingState status) {
    // TODO: implement setTrackingState
    throw UnimplementedError();
  }

  @override
  Future<void> setUser(String? userId) {
    // TODO: implement setUser
    throw UnimplementedError();
  }

  @override
  Future<void> showLastSessionCrashedPopup() {
    // TODO: implement showLastSessionCrashedPopup
    throw UnimplementedError();
  }

  @override
  Future<int?> checkForRatingPop() {
    // TODO: implement checkForRatingPop
    throw UnimplementedError();
  }

  @override
  Future<bool?> isAppticsFeedbackModuleAvailable() {
    // TODO: implement isAppticsFeedbackModuleAvailable
    throw UnimplementedError();
  }

  @override
  // TODO: implement daysBeforeShowingPopupAgain
  int get daysBeforeShowingPopupAgain => throw UnimplementedError();

  @override
  // TODO: implement disableAutoPromptOnFulFillingCriteria
  bool get disableAutoPromptOnFulFillingCriteria => throw UnimplementedError();

  @override
  // TODO: implement disableIfNotInstalledFromPlayStore
  bool get disableIfNotInstalledFromPlayStore => throw UnimplementedError();

  @override
  // TODO: implement maxTimesToShowPopup
  int get maxTimesToShowPopup => throw UnimplementedError();

  @override
  Future<void> openFeedbackScreen() {
    // TODO: implement openFeedbackScreen
    throw UnimplementedError();
  }

  @override
  Future<void> setDaysBeforeShowingPopupAgain(int dayCount) {
    // TODO: implement setDaysBeforeShowingPopupAgain
    throw UnimplementedError();
  }

  @override
  Future<void> setDisableAutoPromptOnFulFillingCriteria(bool isDisable) {
    // TODO: implement setDisableAutoPromptOnFulFillingCriteria
    throw UnimplementedError();
  }

  @override
  Future<void> setDisableIfNotInstalledFromPlayStore(bool ifNotInstalledFromPlayStore) {
    // TODO: implement setDisableIfNotInstalledFromPlayStore
    throw UnimplementedError();
  }

  @override
  Future<void> setMaxTimesToShowPopup(int maxTime) {
    // TODO: implement setMaxTimesToShowPopup
    throw UnimplementedError();
  }

  Future<void> setShowAndroidPlayCoreAlertOnFulFillingCriteria(bool isShow) {
    // TODO: implement setShowAndroidPlayCoreAlertOnFulFillingCriteria
    throw UnimplementedError();
  }

  // TODO: implement showAndroidPlayCoreAlertOnFulFillingCriteria
  bool get showAndroidPlayCoreAlertOnFulFillingCriteria => throw UnimplementedError();

  @override
  Future<void> openPlayStore() {
    // TODO: implement openPlayStore
    throw UnimplementedError();
  }

  @override
  Future<void> sentRatingStats(int criteriaId, PopupAction popupAction) {
    // TODO: implement sentRatingStats
    throw UnimplementedError();
  }


  @override
  Future<void> hardReset() {
    // TODO: implement hardReset
    throw UnimplementedError();
  }

  @override
  Future<void> setCustomConditionValue(String key, String value) {
    // TODO: implement setCustomConditionValue
    throw UnimplementedError();
  }

  @override
  Future<void> setShowStoreAlertOnFulFillingCriteria(bool isShow) {
    // TODO: implement setShowStoreAlertOnFulFillingCriteria
    throw UnimplementedError();
  }

  @override
  // TODO: implement showStoreAlertOnFulFillingCriteria
  bool get showStoreAlertOnFulFillingCriteria => throw UnimplementedError();

  @override
  Future<String?> getStringValue(String key, {bool coldFetch = false, bool fallbackWithOfflineValue = false}) {
    // TODO: implement getStringValue
    throw UnimplementedError();
  }

  @override
  Future<void> updateRatingShown() {
    // TODO: implement updateRatingShown
    throw UnimplementedError();
  }
}

void main() {
  final AppticsFlutterPlatform initialPlatform = AppticsFlutterPlatform.instance;

  test('$MethodChannelAppticsFlutter is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelAppticsFlutter>());
  });

}
